@@ -14,10 +14,8 @@ $ brainreg_bt
 This function is automatically added as a console-accessible command during pip install
 """
 
-import os
 import argparse
-import re
-from btpytools import tools, recipe
+from btpytools import tools
 from brainreg.paths import Paths
 from brainreg.main import main as register
 from brainreg import cli
@@ -76,6 +74,7 @@ def main():
     # Run the registration using brainreg
     args, additional_images_downsample = cli.prep_registration(args)
 
+    # This is the registration function from brainreg
     register(
         atlas_name,
         args.orientation,
@@ -83,6 +82,7 @@ def main():
         args.brainreg_directory,
         args.voxel_sizes,
         arg_groups["NiftyReg registration backend options"],
+        arg_groups["Pre-processing options"],
         sort_input_file=args.sort_input_file,
         n_free_cpus=args.n_free_cpus,
         additional_images_downsample=additional_images_downsample,
@@ -198,8 +198,16 @@ def choose_vox_size(default, args):
     msg = ""
     if run_cli_ui:
 
-        msg = "Select downsampled stack voxel size for registration.\n(Enter a number and press return)\n"
+        msg = (
+            "Select downsampled stack voxel size for registration.\n"
+            "(Enter a number and press return)\n"
+        )
         n = 1
+
+        # Find the index the corresponds to the default voxel size. If this is missing,
+        # we choose the first found voxel size as the default
+        default_index = 0
+
         for t_vox in unique_voxel_sizes:
             msg += "%d. %d micron\n" % (n, t_vox)
             if default == t_vox:
